# BACcore
Business Analysis Core (BACore) is framework around a set of tools for common business analysis work. The main focus of BACore is on documentation and testing. BACore is written in Python.

## Getting Started

1. Download BACore with pip: `pip install bacore`
